@@ -14,6 +14,7 @@
 """Test module for nested types under PyTables."""
 
 from __future__ import print_function
+from __future__ import absolute_import
 import sys
 import itertools
 
@@ -22,9 +23,11 @@ import numpy
 import tables as t
 from tables.utils import SizeType
 from tables.tests import common
-from tables.tests.common import unittest
+from tables.tests.common import unittest, test_filename
 from tables.tests.common import PyTablesTestCase as TestCase
 from tables.description import Description
+import six
+from six.moves import range
 
 minRowIndex = 10
 
@@ -72,23 +75,23 @@ class TestTDescr(t.IsDescription):
 
 # The corresponding nested array description:
 testADescr = [
-    ('x', '(2,)Int32'),
+    ('x', '(2,)int32'),
     ('Info', [
-        ('value', 'Complex64'),
-        ('y2', 'Float64'),
+        ('value', 'complex128'),
+        ('y2', 'float64'),
         ('Info2', [
             ('name', 'a2'),
-            ('value', '(2,)Complex64'),
-            ('y3', '(2,)Float64'),
-            ('z3', '(2,)Int32')]),
+            ('value', '(2,)complex128'),
+            ('y3', '(2,)float64'),
+            ('z3', '(2,)int32')]),
         ('name', 'a2'),
-        ('z2', 'UInt8')]),
+        ('z2', 'uint8')]),
     ('color', 'a2'),
     ('info', [
         ('Name', 'a2'),
-        ('Value', 'Complex64')]),
-    ('y', '(2,2)Float64'),
-    ('z', 'UInt8')]
+        ('Value', 'complex128')]),
+    ('y', '(2,2)float64'),
+    ('z', 'uint8')]
 
 # The corresponding nested array description (brief version):
 testADescr2 = [
@@ -162,7 +165,7 @@ def areDescriptionsEqual(desc1, desc2):
     if len(cols1) != len(cols2):
         return False
 
-    for (colName, colobj1) in cols1.items():
+    for (colName, colobj1) in six.iteritems(cols1):
         colobj2 = cols2[colName]
         if colName == '_v_pos':
             # The comparison may not be quite exhaustive!
@@ -1477,7 +1480,7 @@ class SameNestedReopen(SameNestedTestCase):
 
 
 class NestedTypesWithGaps(common.TestFileMixin, TestCase):
-    h5fname = TestCase._testFilename('nested-type-with-gaps.h5')
+    h5fname = test_filename('nested-type-with-gaps.h5')
 
     correct_descr = """{
   "float": Float32Col(shape=(), dflt=0.0, pos=0),
@@ -1491,12 +1494,13 @@ class NestedTypesWithGaps(common.TestFileMixin, TestCase):
         tbl = self.h5file.get_node('/nestedtype')
         type_descr = repr(tbl.description)
         if common.verbose:
-            print("Type size with no gaps:", tbl.description._v_itemsize)
-            print("And should be: 13")
+            print("Type size with gaps:", tbl.description._v_itemsize)
+            print("And should be: 16")
             print("Representation of the nested type:\n", type_descr)
             print("And should be:\n", self.correct_descr)
+            print("Here are the offsets: ", tbl.description._v_offsets)
 
-        self.assertEqual(tbl.description._v_itemsize, 13)
+        self.assertEqual(tbl.description._v_itemsize, 16)
         self.assertEqual(type_descr, self.correct_descr)
 
         if common.verbose:
@@ -1510,8 +1514,6 @@ def suite():
     niter = 1
     # common.heavy = 1  # uncomment this only for testing purposes
 
-    # theSuite.addTest(unittest.makeSuite(DescriptionTestCase))
-    # theSuite.addTest(unittest.makeSuite(WriteReopen))
     for i in range(niter):
         theSuite.addTest(unittest.makeSuite(DescriptionTestCase))
         theSuite.addTest(unittest.makeSuite(CreateTestCase))
